pub fn block_for(duration: Duration)Expand description
Blocks for at least duration.
This function may require interrupts to be enabled to work correctly.
Panics
Panics if the computed instant overflows.
Avoid panics with try_block_for().
pub fn block_for(duration: Duration)Blocks for at least duration.
This function may require interrupts to be enabled to work correctly.
Panics if the computed instant overflows.
Avoid panics with try_block_for().