embassy-time

Crates

git

Versions

default

Flavors

MockDriver

Struct MockDriver 

pub struct MockDriver(/* private fields */);
A mock driver that can be manually advanced. This is useful for testing code that works with Instant and Duration.

This driver can also be used to test runtime functionality, such as timers, delays, etc.

Example

ⓘ
fn has_a_second_passed(reference: Instant) -> bool {
    Instant::now().duration_since(reference) >= Duration::from_secs(1)
}

fn test_second_passed() {
    let driver = embassy_time::MockDriver::get();
    let reference = Instant::now();
    assert_eq!(false, has_a_second_passed(reference));
    driver.advance(Duration::from_secs(1));
    assert_eq!(true, has_a_second_passed(reference));
}

Implementations

Source

impl MockDriver

pub const fn new() -> Self

Creates a new mock driver.

pub fn get() -> &'static MockDriver

Gets a reference to the global mock driver.

pub fn reset(&self)

Resets the internal state of the mock driver This will clear and deallocate all alarms, and reset the current time to 0.

pub fn advance(&self, duration: Duration)

Advances the time by the specified Duration. Calling any alarm callbacks that are due.